@@ -3,10 +3,10 @@
  * spccache.h
  *	  Tablespace cache.
  *
- * Portions Copyright (c) 1996-2010, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2016, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
- * $PostgreSQL: pgsql/src/include/utils/spccache.h,v 1.2 2010/02/26 02:01:29 momjian Exp $
+ * src/include/utils/spccache.h
  *
  *-------------------------------------------------------------------------
  */
@@ -15,5 +15,6 @@
 
 void get_tablespace_page_costs(Oid spcid, float8 *spc_random_page_cost,
 						  float8 *spc_seq_page_cost);
+int			get_tablespace_io_concurrency(Oid spcid);
 
 #endif   /* SPCCACHE_H */
